Title: [187806] trunk/Source
Revision
187806
Author
mmaxfi...@apple.com
Date
2015-08-03 20:42:00 -0700 (Mon, 03 Aug 2015)

Log Message

Unreviewed post-review feedback on r187797

The correct terminology is "registered" instead of "activated."

Source/WebCore:

No new tests because there is no behavior change.

* platform/graphics/FontPlatformData.h:
* platform/graphics/cocoa/FontPlatformDataCocoa.mm:
(WebCore::FontPlatformData::registeredFont):
(WebCore::FontPlatformData::activatedFont): Deleted.

Source/WebKit/mac:

* WebView/WebHTMLView.mm:
(-[WebHTMLView _updateFontPanel]):

Modified Paths

Diff

Modified: trunk/Source/WebCore/ChangeLog (187805 => 187806)


--- trunk/Source/WebCore/ChangeLog	2015-08-04 03:32:27 UTC (rev 187805)
+++ trunk/Source/WebCore/ChangeLog	2015-08-04 03:42:00 UTC (rev 187806)
@@ -1,5 +1,18 @@
 2015-08-03  Myles C. Maxfield  <mmaxfi...@apple.com>
 
+        Unreviewed post-review feedback on r187797
+
+        The correct terminology is "registered" instead of "activated."
+
+        No new tests because there is no behavior change.
+
+        * platform/graphics/FontPlatformData.h:
+        * platform/graphics/cocoa/FontPlatformDataCocoa.mm:
+        (WebCore::FontPlatformData::registeredFont):
+        (WebCore::FontPlatformData::activatedFont): Deleted.
+
+2015-08-03  Myles C. Maxfield  <mmaxfi...@apple.com>
+
         Clean up casts between NSFont*s and CTFontRefs
         https://bugs.webkit.org/show_bug.cgi?id=147618
 

Modified: trunk/Source/WebCore/platform/graphics/FontPlatformData.h (187805 => 187806)


--- trunk/Source/WebCore/platform/graphics/cocoa/FontPlatformDataCocoa.mm	2015-08-04 03:32:27 UTC (rev 187805)
+++ trunk/Source/WebCore/platform/graphics/cocoa/FontPlatformDataCocoa.mm	2015-08-04 03:42:00 UTC (rev 187806)
@@ -91,7 +91,7 @@
     return m_cgFont == other.m_cgFont;
 }
 
-CTFontRef FontPlatformData::activatedFont() const
+CTFontRef FontPlatformData::registeredFont() const
 {
     CTFontRef platformFont = font();
     ASSERT(platformFont);

Modified: trunk/Source/WebKit/mac/ChangeLog (187805 => 187806)


--- trunk/Source/WebKit/mac/ChangeLog	2015-08-04 03:32:27 UTC (rev 187805)
+++ trunk/Source/WebKit/mac/ChangeLog	2015-08-04 03:42:00 UTC (rev 187806)
@@ -1,5 +1,14 @@
 2015-08-03  Myles C. Maxfield  <mmaxfi...@apple.com>
 
+        Unreviewed post-review feedback on r187797
+
+        The correct terminology is "registered" instead of "activated."
+
+        * WebView/WebHTMLView.mm:
+        (-[WebHTMLView _updateFontPanel]):
+
+2015-08-03  Myles C. Maxfield  <mmaxfi...@apple.com>
+
         Clean up casts between NSFont*s and CTFontRefs
         https://bugs.webkit.org/show_bug.cgi?id=147618
 

Modified: trunk/Source/WebKit/mac/WebView/WebHTMLView.mm (187805 => 187806)


--- trunk/Source/WebKit/mac/WebView/WebHTMLView.mm	2015-08-04 03:32:27 UTC (rev 187805)
+++ trunk/Source/WebKit/mac/WebView/WebHTMLView.mm	2015-08-04 03:42:00 UTC (rev 187806)
@@ -5485,7 +5485,7 @@
     NSDictionary *attributes = nil;
     if (Frame* coreFrame = core([self _frame])) {
         if (const Font* fd = coreFrame->editor().fontForSelection(multipleFonts))
-            font = (NSFont *)fd->platformData().activatedFont();
+            font = (NSFont *)fd->platformData().registeredFont();
         attributes = coreFrame->editor().fontAttributesForSelectionStart();
     }
 
_______________________________________________
webkit-changes mailing list
webkit-changes@lists.webkit.org
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to
--- trunk/Source/WebCore/platform/graphics/FontPlatformData.h	2015-08-04 03:32:27 UTC (rev 187805)
+++ trunk/Source/WebCore/platform/graphics/FontPlatformData.h	2015-08-04 03:42:00 UTC (rev 187806)
@@ -108,7 +108,7 @@
     bool useGDI() const { return m_useGDI; }
 #elif PLATFORM(COCOA)
     CTFontRef font() const { return m_font.get(); }
-    WEBCORE_EXPORT CTFontRef activatedFont() const; // Returns nullptr iff the font is not activated (otherwise returns font()).
+    WEBCORE_EXPORT CTFontRef registeredFont() const; // Returns nullptr iff the font is not registered, such as web fonts (otherwise returns font()).
     void setFont(CTFontRef);
 
     CTFontRef ctFont() const;

Modified: trunk/Source/WebCore/platform/graphics/cocoa/FontPlatformDataCocoa.mm (187805 => 187806)

